@@ -825,6 +825,10 @@ class FilesystemService:
         check()
         return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).SetBlobStatus, request)
 
+    def ShareFile(self, request):
+        check()
+        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ShareFile, request)
+
     def UploadPresigned(self, request):
         check()
         return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).UploadPresigned, request)
@@ -922,6 +926,12 @@ class FilesystemService:
     def SetBlobStatusResponse(self, **kwargs):
         return filesystem_pb2.SetBlobStatusResponse(**kwargs)
 
+    def ShareFileRequest(self, **kwargs):
+        return filesystem_pb2.ShareFileRequest(**kwargs)
+
+    def ShareFileResponse(self, **kwargs):
+        return filesystem_pb2.ShareFileResponse(**kwargs)
+
     def UploadPresignedRequest(self, **kwargs):
         return filesystem_pb2.UploadPresignedRequest(**kwargs)
 
